# 衣韵智裁UML编写
# 一、Schema范式设计

## 虚拟试衣模块
* 测试目标
    - 验证虚拟试衣技术的真实感和准确性，确保用户能够实时、直观地查看服装效果，降低试错成本。

* 测试方法与步骤
    - 用户选择：
        - 选取不同体型、肤色、风格偏好的用户作为测试样本。对每个用户进行详细的身材数据测量，确保数据的准确性。
    - 虚拟试衣体验：
        - 使用虚拟试衣技术为用户生成三维模型，进行虚拟试衣。
        展示不同风格、面料、尺寸的服装在三维模型上的效果。
    - 用户反馈收集：
        - 组织用户对虚拟试衣效果进行评审，收集其对试衣效果的满意度、真实感、准确性等方面的反馈。记录用户提出的改进意见和建议。

* 技术优化与调整：
    - 根据用户反馈和技术测试结果对虚拟试衣技术进行优化调整，提高试衣效果的真实感和准确性。引入更先进的渲染技术和更丰富的场景选择，提升用户体验。

* 预期结果
    - 虚拟试衣技术能够为用户提供真实、准确的试衣体验，用户满意度达到较高水平，且技术具有可扩展性和可升级性。

## 1、表设计
### 用户表（user）
- objectId: 唯一标识符
- createdAt: 创建时间
- name: String (用户姓名)
- bodyType: String (体型)
- skinColor: String (肤色)
- stylePreference: String (风格偏好)
- measurements: Object (身材数据，包含胸围、腰围、臀围等)
### 试衣体验表（VirtualTryOn）
- objectId: 唯一标识符
- createdAt: 创建时间
- user: Pointer (关联用户)
- outfitStyle: String (服装风格)
- fabricType: String (面料类型)
- size: String (尺寸)
- threeDModel: String (三维模型链接)
### 用户反馈表（UserFeedback）
- objectId: 唯一标识符
- createdAt: 创建时间
- virtualTryOn: Pointer (关联虚拟试衣体验)
- satisfactionLevel: Number (满意度评分)
- realismRating: Number (真实感评分)
- accuracyRating: Number (准确性评分)
- feedbackComments: String (用户反馈意见)
### 技术优化表（TechnicalOptimization）
- objectId: 唯一标识符
- createdAt: 创建时间
- userFeedback: Pointer (关联用户反馈)
- optimizationDetails: String (优化细节)
- improvementSuggestions: String (改进建议)

## 2、PlantUML 类图表示
以下是使用PlantUML表示的类图：

```plantuml
@startuml
class User {
    +objectId: String
    +createdAt: Date
    +name: String
    +bodyType: String
    +skinColor: String
    +stylePreference: String
    +measurements: Object
}

class VirtualTryOn {
    +objectId: String
    +createdAt: Date
    +user: Pointer
    +outfitStyle: String
    +fabricType: String
    +size: String
    +threeDModel: String
}

class UserFeedback {
    +objectId: String
    +createdAt: Date
    +virtualTryOn: Pointer
    +satisfactionLevel: Number
    +realismRating: Number
    +accuracyRating: Number
    +feedbackComments: String
}

class TechnicalOptimization {
    +objectId: String
    +createdAt: Date
    +userFeedback: Pointer
    +optimizationDetails: String
    +improvementSuggestions: String
}

User "1" -- "0..*" VirtualTryOn : has
VirtualTryOn "1" -- "0..*" UserFeedback : receives
UserFeedback "1" -- "0..*" TechnicalOptimization : leads to
@enduml
```

## 3、设计说明
- 用户表（User）: 存储用户的基本信息和身材数据，以便进行个性化的虚拟试衣体验。
- 试衣体验表（VirtualTryOn）: 记录每个用户的虚拟试衣体验，包括所选服装的风格、面料和三维模型信息。
- 用户反馈表（UserFeedback）: 收集用户对虚拟试衣体验的反馈，包括满意度、真实感和准确性评分以及具体的意见。
- 科技优化表（TechnicalOptimization）: 存储基于用户反馈进行的技术优化和改进建议，以提升虚拟试衣技术的效果和用户体验。